@@ -1,4 +1,9 @@
 # -*- coding: utf-8 -*-
+"""
+In ``tinygp``, "transforms" are a powerful and relatively safe way to build
+extremely expressive kernels without resorting to writing a fully fledged custom
+kernel. More details can be found in the :ref:`transforms` tutorial.
+"""
 
 from __future__ import annotations
 
@@ -10,10 +15,11 @@ from typing import Any, Callable, Sequence, Union
 import jax.numpy as jnp
 from jax.scipy import linalg
 
-from .kernels import Kernel
-from .types import JAXArray
+from tinygp.helpers import JAXArray, dataclass
+from tinygp.kernels.base import Kernel
 
 
+@dataclass
 class Transform(Kernel):
     """Apply a transformation to the input coordinates of the kernel
 
@@ -23,16 +29,15 @@ class Transform(Kernel):
         kernel (Kernel): The kernel to use in the transformed space.
     """
 
-    # This type signature is a hack for Sphinx sphinx-doc/sphinx#9736
-    def __init__(self, transform: Callable[[Any], Any], kernel: Kernel):
-        self.transform = transform
-        self.kernel = kernel
+    transform: Callable[[Any], Any]
+    kernel: Kernel
 
     def evaluate(self, X1: JAXArray, X2: JAXArray) -> JAXArray:
-        return self.kernel.evaluate(self.transform(X1), self.transform(X2))
+        return self.kernel.evaluate(self.transform(X1), self.transform(X2))  # type: ignore
 
 
-class Linear(Transform):
+@dataclass
+class Linear(Kernel):
     """Apply a linear transformation to the input coordinates of the kernel
 
     For example, the following transformed kernels are all equivalent, but the
@@ -54,18 +59,21 @@ class Linear(Transform):
         kernel (Kernel): The kernel to use in the transformed space.
     """
 
-    def __init__(self, scale: JAXArray, kernel: Kernel):
-        self.scale = scale
-        if jnp.ndim(scale) < 2:
-            self.transform = partial(jnp.multiply, scale)
-        elif jnp.ndim(scale) == 2:
-            self.transform = partial(jnp.dot, scale)
+    scale: JAXArray
+    kernel: Kernel
+
+    def evaluate(self, X1: JAXArray, X2: JAXArray) -> JAXArray:
+        if jnp.ndim(self.scale) < 2:
+            transform = partial(jnp.multiply, self.scale)
+        elif jnp.ndim(self.scale) == 2:
+            transform = partial(jnp.dot, self.scale)
         else:
             raise ValueError("'scale' must be 0-, 1-, or 2-dimensional")
-        self.kernel = kernel
+        return self.kernel.evaluate(transform(X1), transform(X2))
 
 
-class Cholesky(Transform):
+@dataclass
+class Cholesky(Kernel):
     """Apply a Cholesky transformation to the input coordinates of the kernel
 
     For example, the following transformed kernels are all equivalent, but the
@@ -83,26 +91,24 @@ class Cholesky(Transform):
 
     Args:
         factor (JAXArray): A 0-, 1-, or 2-dimensional array specifying the
-            Cholesky factor. If 2-dimensional, this must be a lower or
-            upper triangular matrix as specified by ``lower``, but this is
-            not checked.
+            Cholesky factor. If 2-dimensional, this must be a lower
+            triangular matrix, but this is not checked.
         kernel (Kernel): The kernel to use in the transformed space.
-        lower: (bool, optional): Is ``factor`` lower (vs upper) triangular.
     """
 
-    def __init__(
-        self, factor: JAXArray, kernel: Kernel, *, lower: bool = True
-    ):
-        self.factor = factor
-        if jnp.ndim(factor) < 2:
-            self.transform = partial(jnp.multiply, 1.0 / factor)
-        elif jnp.ndim(factor) == 2:
-            self.transform = partial(
-                linalg.solve_triangular, factor, lower=lower
+    factor: JAXArray
+    kernel: Kernel
+
+    def evaluate(self, X1: JAXArray, X2: JAXArray) -> JAXArray:
+        if jnp.ndim(self.factor) < 2:
+            transform = partial(jnp.multiply, 1.0 / self.factor)
+        elif jnp.ndim(self.factor) == 2:
+            transform = partial(
+                linalg.solve_triangular, self.factor, lower=True
             )
         else:
             raise ValueError("'scale' must be 0-, 1-, or 2-dimensional")
-        self.kernel = kernel
+        return self.kernel.evaluate(transform(X1), transform(X2))
 
     @classmethod
     def from_parameters(
@@ -128,10 +134,11 @@ class Cholesky(Transform):
         factor = jnp.zeros((ndim, ndim))
         factor = factor.at[jnp.diag_indices(ndim)].add(diagonal)
         factor = factor.at[jnp.tril_indices(ndim, -1)].add(off_diagonal)
-        return cls(factor, kernel, lower=True)
+        return cls(factor, kernel)
 
 
-class Subspace(Transform):
+@dataclass
+class Subspace(Kernel):
     """A kernel transform that selects a subset of the input dimensions
 
     For example, the following kernel only depends on the coordinates in the
@@ -153,6 +160,8 @@ class Subspace(Transform):
         kernel (Kernel): The kernel to use in the transformed space.
     """
 
-    def __init__(self, axis: Union[Sequence[int], int], kernel: Kernel):
-        self.transform = lambda X: X[axis]
-        self.kernel = kernel
+    axis: Union[Sequence[int], int]
+    kernel: Kernel
+
+    def evaluate(self, X1: JAXArray, X2: JAXArray) -> JAXArray:
+        return self.kernel.evaluate(X1[self.axis], X2[self.axis])
