@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 # mypy: ignore-errors
 
+import warnings
+
 import numpy as np
 import pytest
 
@@ -8,10 +10,6 @@ from tinygp import GaussianProcess, kernels
 
 george = pytest.importorskip("george")
 
-from jax.config import config
-
-config.update("jax_enable_x64", True)
-
 
 @pytest.fixture
 def random():
@@ -47,11 +45,11 @@ def kernel(request):
 def periodic_kernel(request):
     return {
         "Cosine": (
-            kernels.Cosine(period=2.3),
+            kernels.Cosine(scale=2.3),
             george.kernels.CosineKernel(log_period=np.log(2.3)),
         ),
         "ExpSineSquared": (
-            kernels.ExpSineSquared(period=2.3, gamma=1.3),
+            kernels.ExpSineSquared(scale=2.3, gamma=1.3),
             george.kernels.ExpSine2Kernel(gamma=1.3, log_period=np.log(2.3)),
         ),
     }[request.param]
@@ -66,19 +64,19 @@ def stationary_kernel(request):
     return {
         "Exp": (
             kernels.Exp(scale),
-            george.kernels.ExpKernel(scale ** 2),
+            george.kernels.ExpKernel(scale**2),
         ),
         "ExpSquared": (
             kernels.ExpSquared(scale),
-            george.kernels.ExpSquaredKernel(scale ** 2),
+            george.kernels.ExpSquaredKernel(scale**2),
         ),
         "Matern32": (
             kernels.Matern32(scale),
-            george.kernels.Matern32Kernel(scale ** 2),
+            george.kernels.Matern32Kernel(scale**2),
         ),
         "Matern52": (
             kernels.Matern52(scale),
-            george.kernels.Matern52Kernel(scale ** 2),
+            george.kernels.Matern52Kernel(scale**2),
         ),
         "RationalQuadratic": (
             kernels.RationalQuadratic(alpha=1.5),
@@ -119,48 +117,51 @@ def compare_gps(random, tiny_kernel, george_kernel):
 
     # Likelihood
     np.testing.assert_allclose(
-        tiny_gp.condition(y), george_gp.log_likelihood(y)
+        tiny_gp.log_probability(y), george_gp.log_likelihood(y)
     )
 
     # Filtering
-    np.testing.assert_allclose(
-        tiny_gp.predict(y),
-        george_gp.predict(y, x, return_var=False, return_cov=False),
-    )
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", DeprecationWarning)
 
-    # Filtering with explicit value
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, x),
-        george_gp.predict(y, x, return_var=False, return_cov=False),
-    )
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, t),
-        george_gp.predict(y, t, return_var=False, return_cov=False),
-    )
+        np.testing.assert_allclose(
+            tiny_gp.predict(y),
+            george_gp.predict(y, x, return_var=False, return_cov=False),
+        )
 
-    # Variance
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, return_var=True)[1],
-        george_gp.predict(y, x, return_var=True, return_cov=False)[1],
-        rtol=1e-5,
-    )
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, t, return_var=True)[1],
-        george_gp.predict(y, t, return_var=True, return_cov=False)[1],
-        rtol=1e-5,
-    )
+        # Filtering with explicit value
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, x),
+            george_gp.predict(y, x, return_var=False, return_cov=False),
+        )
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, t),
+            george_gp.predict(y, t, return_var=False, return_cov=False),
+        )
 
-    # Covariance
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, return_cov=True)[1],
-        george_gp.predict(y, x, return_var=False, return_cov=True)[1],
-        atol=1e-5,
-    )
-    np.testing.assert_allclose(
-        tiny_gp.predict(y, t, return_cov=True)[1],
-        george_gp.predict(y, t, return_var=False, return_cov=True)[1],
-        atol=1e-5,
-    )
+        # Variance
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, return_var=True)[1],
+            george_gp.predict(y, x, return_var=True, return_cov=False)[1],
+            atol=1e-7,
+        )
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, t, return_var=True)[1],
+            george_gp.predict(y, t, return_var=True, return_cov=False)[1],
+            atol=1e-7,
+        )
+
+        # Covariance
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, return_cov=True)[1],
+            george_gp.predict(y, x, return_var=False, return_cov=True)[1],
+            atol=1e-7,
+        )
+        np.testing.assert_allclose(
+            tiny_gp.predict(y, t, return_cov=True)[1],
+            george_gp.predict(y, t, return_var=False, return_cov=True)[1],
+            atol=1e-7,
+        )
 
 
 def test_kernel_value(random, kernel):
